==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/ClusterControlCore/src/com/clustercontrol/notify/action/AddNotify.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.notify.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.jms.JMSException;
import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.notify.bean.NotifyInfo;
import com.clustercontrol.notify.ejb.session.NotifyController;
import com.clustercontrol.notify.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * ξϿ륯饹Ǥ
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class AddNotify {

    /**
     * ξɲäޤ
     * 
     * @param info ξ
     * @return Ͽ硢true
     */
    public boolean add(NotifyInfo info) {
    	
        NotifyController notify = EjbConnectionManager.getConnectionManager().getNotifyController();

        boolean result = false;
        try {
        	result = notify.addNotify(info);
        	return result;
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// ʤξ硢顼ɽ
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (CreateException e) {
        } catch (NamingException e) {
        } catch (JMSException e) {
        }
        return false;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/ClusterControlCore/src/com/clustercontrol/notify/action/AddNotify.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.notify.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.jms.JMSException;
import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;

import com.clustercontrol.notify.bean.NotifyInfo;
import com.clustercontrol.notify.ejb.session.NotifyController;
import com.clustercontrol.notify.util.EjbConnectionManager;
import com.clustercontrol.util.Messages;

/**
 * 通知情報を登録するクラスです。
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class AddNotify {

    /**
     * 通知情報を追加します。
     * 
     * @param info 通知情報
     * @return 登録に成功した場合、true
     */
    public boolean add(NotifyInfo info) {
    	
        NotifyController notify = EjbConnectionManager.getConnectionManager().getNotifyController();

        boolean result = false;
        try {
        	result = notify.addNotify(info);
        	return result;
        } catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
        } catch (CreateException e) {
        } catch (NamingException e) {
        } catch (JMSException e) {
        }
        return false;
    }
}
